summaryrefslogtreecommitdiff
path: root/sot/source/base
diff options
context:
space:
mode:
authorXiaofei Zhang <Zhangxiaofei@openoffice.org>2010-07-29 10:56:19 +0800
committerXiaofei Zhang <Zhangxiaofei@openoffice.org>2010-07-29 10:56:19 +0800
commitd210c6ccc30466e98240c1409df0550514668d68 (patch)
tree0c94d52ecaebd283a92275cb372d5ddf926f5131 /sot/source/base
parent7f0993d43019a0ccb7f89c11fc23704c063b902f (diff)
#i112600#: clean up l10ntools, rsc, sot, svl, tools and unotools
Diffstat (limited to 'sot/source/base')
-rw-r--r--sot/source/base/exchange.cxx34
-rw-r--r--sot/source/base/factory.cxx24
-rw-r--r--sot/source/base/filelist.cxx14
-rw-r--r--sot/source/base/formats.cxx56
-rw-r--r--sot/source/base/object.cxx74
5 files changed, 101 insertions, 101 deletions
diff --git a/sot/source/base/exchange.cxx b/sot/source/base/exchange.cxx
index 67c2b64f105f..2b51162df3a0 100644
--- a/sot/source/base/exchange.cxx
+++ b/sot/source/base/exchange.cxx
@@ -237,11 +237,11 @@ static List& InitFormats_Impl()
|*
|* Beschreibung CLIP.SDW
*************************************************************************/
-ULONG SotExchange::RegisterFormatName( const String& rName )
+sal_uIntPtr SotExchange::RegisterFormatName( const String& rName )
{
const DataFlavorRepresentation *pFormatArray_Impl = FormatArray_Impl::get();
// teste zuerst die Standard - Name
- ULONG i, nMax = SOT_FORMAT_FILE_LIST;
+ sal_uIntPtr i, nMax = SOT_FORMAT_FILE_LIST;
for( i = SOT_FORMAT_STRING; i <= nMax; ++i )
if( COMPARE_EQUAL == rName.CompareToAscii( pFormatArray_Impl[ i ].pName ) )
return i;
@@ -277,11 +277,11 @@ ULONG SotExchange::RegisterFormatName( const String& rName )
return nMax + SOT_FORMATSTR_ID_USER_END + 1;
}
-ULONG SotExchange::RegisterFormatMimeType( const String& rMimeType )
+sal_uIntPtr SotExchange::RegisterFormatMimeType( const String& rMimeType )
{
const DataFlavorRepresentation *pFormatArray_Impl = FormatArray_Impl::get();
// teste zuerst die Standard - Name
- ULONG i, nMax = SOT_FORMAT_FILE_LIST;
+ sal_uIntPtr i, nMax = SOT_FORMAT_FILE_LIST;
for( i = SOT_FORMAT_STRING; i <= nMax; ++i )
if( rMimeType.EqualsAscii( pFormatArray_Impl[ i ].pMimeType ) )
return i;
@@ -318,9 +318,9 @@ ULONG SotExchange::RegisterFormatMimeType( const String& rMimeType )
|*
|* Beschreibung CLIP.SDW
*************************************************************************/
-ULONG SotExchange::RegisterFormat( const DataFlavor& rFlavor )
+sal_uIntPtr SotExchange::RegisterFormat( const DataFlavor& rFlavor )
{
- ULONG nRet = GetFormat( rFlavor );
+ sal_uIntPtr nRet = GetFormat( rFlavor );
if( !nRet )
{
@@ -338,7 +338,7 @@ ULONG SotExchange::RegisterFormat( const DataFlavor& rFlavor )
|*
*************************************************************************/
-sal_Bool SotExchange::GetFormatDataFlavor( ULONG nFormat, DataFlavor& rFlavor )
+sal_Bool SotExchange::GetFormatDataFlavor( sal_uIntPtr nFormat, DataFlavor& rFlavor )
{
sal_Bool bRet;
@@ -376,11 +376,11 @@ sal_Bool SotExchange::GetFormatDataFlavor( ULONG nFormat, DataFlavor& rFlavor )
/*************************************************************************
|*
-|* SotExchange::GetFormatMimeType( ULONG nFormat )
+|* SotExchange::GetFormatMimeType( sal_uIntPtr nFormat )
|*
*************************************************************************/
-String SotExchange::GetFormatMimeType( ULONG nFormat )
+String SotExchange::GetFormatMimeType( sal_uIntPtr nFormat )
{
String sMimeType;
if( SOT_FORMATSTR_ID_USER_END >= nFormat )
@@ -406,10 +406,10 @@ String SotExchange::GetFormatMimeType( ULONG nFormat )
|*
*************************************************************************/
-ULONG SotExchange::GetFormatIdFromMimeType( const String& rMimeType )
+sal_uIntPtr SotExchange::GetFormatIdFromMimeType( const String& rMimeType )
{
const DataFlavorRepresentation *pFormatArray_Impl = FormatArray_Impl::get();
- ULONG i, nMax = SOT_FORMAT_FILE_LIST;
+ sal_uIntPtr i, nMax = SOT_FORMAT_FILE_LIST;
for( i = SOT_FORMAT_STRING; i <= nMax; ++i )
if( rMimeType.EqualsAscii( pFormatArray_Impl[ i ].pMimeType ) )
return i;
@@ -443,12 +443,12 @@ ULONG SotExchange::GetFormatIdFromMimeType( const String& rMimeType )
|*
|* Beschreibung CLIP.SDW
*************************************************************************/
-ULONG SotExchange::GetFormat( const DataFlavor& rFlavor )
+sal_uIntPtr SotExchange::GetFormat( const DataFlavor& rFlavor )
{
// teste zuerst die Standard - Name
const ::rtl::OUString& rMimeType = rFlavor.MimeType;
const String aMimeType( rMimeType );
- ULONG i, nMax = SOT_FORMAT_FILE_LIST;
+ sal_uIntPtr i, nMax = SOT_FORMAT_FILE_LIST;
const DataFlavorRepresentation *pFormatArray_Impl = FormatArray_Impl::get();
for( i = SOT_FORMAT_STRING; i <= nMax; ++i )
if( aMimeType.EqualsAscii( pFormatArray_Impl[ i ].pMimeType ) )
@@ -482,7 +482,7 @@ ULONG SotExchange::GetFormat( const DataFlavor& rFlavor )
|*
|* Beschreibung CLIP.SDW
*************************************************************************/
-String SotExchange::GetFormatName( ULONG nFormat )
+String SotExchange::GetFormatName( sal_uIntPtr nFormat )
{
DataFlavor aFlavor;
String aRet;
@@ -493,7 +493,7 @@ String SotExchange::GetFormatName( ULONG nFormat )
return aRet;
}
-BOOL SotExchange::IsInternal( const SvGlobalName& rName )
+sal_Bool SotExchange::IsInternal( const SvGlobalName& rName )
{
if ( rName == SvGlobalName(SO3_SW_CLASSID_60) ||
rName == SvGlobalName(SO3_SC_CLASSID_60) ||
@@ -503,6 +503,6 @@ BOOL SotExchange::IsInternal( const SvGlobalName& rName )
rName == SvGlobalName(SO3_SM_CLASSID_60) ||
rName == SvGlobalName(SO3_SWWEB_CLASSID_60) ||
rName == SvGlobalName(SO3_SWGLOB_CLASSID_60) )
- return TRUE;
- return FALSE;
+ return sal_True;
+ return sal_False;
}
diff --git a/sot/source/base/factory.cxx b/sot/source/base/factory.cxx
index 4934f99e78c6..5c4757188f38 100644
--- a/sot/source/base/factory.cxx
+++ b/sot/source/base/factory.cxx
@@ -96,10 +96,10 @@ void SotFactory::DeInit()
aStr += " Count: ";
aStr += p->GetRefCount();
DBG_TRACE( "\tReferences:" );
- p->TestObjRef( FALSE );
+ p->TestObjRef( sal_False );
#ifdef TEST_INVARIANT
DBG_TRACE( "\tInvariant:" );
- p->TestInvariant( TRUE );
+ p->TestInvariant( sal_True );
#endif
p = pObjList->Next();
}
@@ -129,7 +129,7 @@ void SotFactory::DeInit()
if( pSotData->pDataFlavorList )
{
- for( ULONG i = 0, nMax = pSotData->pDataFlavorList->Count(); i < nMax; i++ )
+ for( sal_uIntPtr i = 0, nMax = pSotData->pDataFlavorList->Count(); i < nMax; i++ )
delete (::com::sun::star::datatransfer::DataFlavor*) pSotData->pDataFlavorList->GetObject( i );
delete pSotData->pDataFlavorList;
pSotData->pDataFlavorList = NULL;
@@ -194,7 +194,7 @@ SotFactory::~SotFactory()
|*
|* Beschreibung Zugriffsmethoden auf SotData_Impl-Daten
*************************************************************************/
-UINT32 SotFactory::GetSvObjectCount()
+sal_uInt32 SotFactory::GetSvObjectCount()
{
return SOTDATA()->nSvObjCount;
}
@@ -295,10 +295,10 @@ void SotFactory::TestInvariant()
SotData_Impl * pSotData = SOTDATA();
if( pSotData->pObjectList )
{
- ULONG nCount = pSotData->pObjectList->Count();
- for( ULONG i = 0; i < nCount ; i++ )
+ sal_uIntPtr nCount = pSotData->pObjectList->Count();
+ for( sal_uIntPtr i = 0; i < nCount ; i++ )
{
- pSotData->pObjectList->GetObject( i )->TestInvariant( FALSE );
+ pSotData->pObjectList->GetObject( i )->TestInvariant( sal_False );
}
}
#endif
@@ -388,17 +388,17 @@ void * SotFactory::AggCastAndAddRef
|*
|* Beschreibung
*************************************************************************/
-BOOL SotFactory::Is( const SotFactory * pSuperCl ) const
+sal_Bool SotFactory::Is( const SotFactory * pSuperCl ) const
{
if( this == pSuperCl )
- return TRUE;
+ return sal_True;
- for( USHORT i = 0; i < nSuperCount; i++ )
+ for( sal_uInt16 i = 0; i < nSuperCount; i++ )
{
if( pSuperClasses[ i ]->Is( pSuperCl ) )
- return TRUE;
+ return sal_True;
}
- return FALSE;
+ return sal_False;
}
diff --git a/sot/source/base/filelist.cxx b/sot/source/base/filelist.cxx
index 4f854add304d..80828e596538 100644
--- a/sot/source/base/filelist.cxx
+++ b/sot/source/base/filelist.cxx
@@ -61,8 +61,8 @@ FileList::~FileList()
void FileList::ClearAll( void )
{
// Strings in der Liste loeschen
- ULONG nCount = pStrList->Count();
- for( ULONG i = 0 ; i < nCount ; i++ )
+ sal_uIntPtr nCount = pStrList->Count();
+ for( sal_uIntPtr i = 0 ; i < nCount ; i++ )
delete pStrList->GetObject( i );
// Liste loeschen
@@ -81,8 +81,8 @@ FileList& FileList::operator=( const FileList& rFileList )
*pStrList = *rFileList.pStrList;
// Strings in der Liste kopieren
- ULONG nCount = pStrList->Count();
- for( ULONG i = 0 ; i < nCount ; i++ )
+ sal_uIntPtr nCount = pStrList->Count();
+ for( sal_uIntPtr i = 0 ; i < nCount ; i++ )
pStrList->Replace( new String( *rFileList.pStrList->GetObject( i ) ), i );
return *this;
@@ -94,7 +94,7 @@ FileList& FileList::operator=( const FileList& rFileList )
|*
\*************************************************************************/
-ULONG FileList::GetFormat()
+sal_uIntPtr FileList::GetFormat()
{
return FORMAT_FILE_LIST;
}
@@ -184,7 +184,7 @@ void FileList::AppendFile( const String& rStr )
pStrList->Insert( new String( rStr ) , pStrList->Count() );
}
-String FileList::GetFile( ULONG i ) const
+String FileList::GetFile( sal_uIntPtr i ) const
{
String aStr;
if( i < pStrList->Count() )
@@ -192,7 +192,7 @@ String FileList::GetFile( ULONG i ) const
return aStr;
}
-ULONG FileList::Count( void ) const
+sal_uIntPtr FileList::Count( void ) const
{
return pStrList->Count();
}
diff --git a/sot/source/base/formats.cxx b/sot/source/base/formats.cxx
index baddde6e716f..10b6958ca4ac 100644
--- a/sot/source/base/formats.cxx
+++ b/sot/source/base/formats.cxx
@@ -46,9 +46,9 @@ using namespace::com::sun::star::datatransfer;
struct SotAction_Impl
{
- ULONG nFormatId; // Clipboard Id
- USHORT nAction; // Action Id
- BYTE nContextCheckId; // additional check of content in clipboard
+ sal_uIntPtr nFormatId; // Clipboard Id
+ sal_uInt16 nAction; // Action Id
+ sal_uInt8 nContextCheckId; // additional check of content in clipboard
};
@@ -68,7 +68,7 @@ struct SotAction_Impl
struct SotDestinationEntry_Impl
{
- USHORT nDestination;
+ sal_uInt16 nDestination;
const SotAction_Impl* aDefaultActions;
const SotAction_Impl* aMoveActions;
const SotAction_Impl* aCopyActions;
@@ -1283,7 +1283,7 @@ static SotDestinationEntry_Impl __READONLY_DATA aDestinationArray[] = \
// - new style GetExchange methods -
// ---------------------------------
-sal_Bool IsFormatSupported( const DataFlavorExVector& rDataFlavorExVector, ULONG nId )
+sal_Bool IsFormatSupported( const DataFlavorExVector& rDataFlavorExVector, sal_uIntPtr nId )
{
DataFlavorExVector::iterator aIter( ( (DataFlavorExVector&) rDataFlavorExVector ).begin() );
DataFlavorExVector::iterator aEnd( ( (DataFlavorExVector&) rDataFlavorExVector ).end() );
@@ -1303,14 +1303,14 @@ sal_Bool IsFormatSupported( const DataFlavorExVector& rDataFlavorExVector, ULONG
// -----------------------------------------------------------------------------
-static BOOL CheckTransferableContext_Impl( const Reference< XTransferable >* pxTransferable, const SotAction_Impl&
+static sal_Bool CheckTransferableContext_Impl( const Reference< XTransferable >* pxTransferable, const SotAction_Impl&
#ifdef WNT
rEntry
#endif
)
{
DataFlavor aFlavor;
- BOOL bRet = TRUE;
+ sal_Bool bRet = sal_True;
try
{
@@ -1323,7 +1323,7 @@ rEntry
{
case FILEGRPDSC_ONLY_URL:
{
- bRet = FALSE;
+ bRet = sal_False;
if( SotExchange::GetFormatDataFlavor( SOT_FORMATSTR_ID_FILECONTENT, aFlavor ) &&
(*pxTransferable)->isDataFlavorSupported( aFlavor ) &&
@@ -1367,11 +1367,11 @@ rEntry
// -----------------------------------------------------------------------------
-static USHORT GetTransferableAction_Impl(
+static sal_uInt16 GetTransferableAction_Impl(
const DataFlavorExVector& rDataFlavorExVector,
const SotAction_Impl* pArray,
- ULONG& rFormat,
- ULONG nOnlyTestFormat,
+ sal_uIntPtr& rFormat,
+ sal_uIntPtr nOnlyTestFormat,
const Reference< XTransferable >* pxTransferable )
{
try
@@ -1380,11 +1380,11 @@ static USHORT GetTransferableAction_Impl(
{
DataFlavor aFlavor;
const SotAction_Impl* pArrayStart = pArray;
- ULONG nId = pArray->nFormatId;
+ sal_uIntPtr nId = pArray->nFormatId;
#if OSL_DEBUG_LEVEL > 1
// used for testing a specific format - change in the debugger the value
- static ULONG nChkFormat = 0;
+ static sal_uIntPtr nChkFormat = 0;
if( nChkFormat )
{
for( ; 0xffff != pArray->nFormatId &&
@@ -1454,13 +1454,13 @@ static USHORT GetTransferableAction_Impl(
// -----------------------------------------------------------------------------
-USHORT SotExchange::GetExchangeAction( const DataFlavorExVector& rDataFlavorExVector,
- USHORT nDestination,
- USHORT nSourceOptions,
- USHORT nUserAction,
- ULONG& rFormat,
- USHORT& rDefaultAction,
- ULONG nOnlyTestFormat,
+sal_uInt16 SotExchange::GetExchangeAction( const DataFlavorExVector& rDataFlavorExVector,
+ sal_uInt16 nDestination,
+ sal_uInt16 nSourceOptions,
+ sal_uInt16 nUserAction,
+ sal_uIntPtr& rFormat,
+ sal_uInt16& rDefaultAction,
+ sal_uIntPtr nOnlyTestFormat,
const Reference< XTransferable >* pxTransferable )
{
// hier wird jetzt die oben definierte Tabelle "implementiert"
@@ -1568,11 +1568,11 @@ USHORT SotExchange::GetExchangeAction( const DataFlavorExVector& rDataFlavorExVe
// -----------------------------------------------------------------------------
-USHORT SotExchange::GetExchangeAction(
+sal_uInt16 SotExchange::GetExchangeAction(
const Reference< XTransferable >& rxTransferable,
- USHORT nDestination, USHORT nSourceOptions,
- USHORT nUserAction, ULONG& rFormat,
- USHORT& rDefaultAction, ULONG nOnlyTestFormat )
+ sal_uInt16 nDestination, sal_uInt16 nSourceOptions,
+ sal_uInt16 nUserAction, sal_uIntPtr& rFormat,
+ sal_uInt16& rDefaultAction, sal_uIntPtr nOnlyTestFormat )
{
DataFlavorExVector aVector;
@@ -1625,9 +1625,9 @@ USHORT SotExchange::GetExchangeAction(
nOnlyTestFormat, &rxTransferable ) );
}
-USHORT SotExchange::IsChart( const SvGlobalName& rName )
+sal_uInt16 SotExchange::IsChart( const SvGlobalName& rName )
{
- USHORT nRet=0;
+ sal_uInt16 nRet=0;
// if ( rName == SvGlobalName( SO3_SCH_CLASSID_8 ) )
// nRet = SOFFICE_FILEFORMAT_8;
// else
@@ -1643,9 +1643,9 @@ USHORT SotExchange::IsChart( const SvGlobalName& rName )
return nRet;
}
-USHORT SotExchange::IsMath( const SvGlobalName& rName )
+sal_uInt16 SotExchange::IsMath( const SvGlobalName& rName )
{
- USHORT nRet=0;
+ sal_uInt16 nRet=0;
// if ( rName == SvGlobalName( SO3_SM_CLASSID_8 ) )
// nRet = SOFFICE_FILEFORMAT_8;
// else
diff --git a/sot/source/base/object.cxx b/sot/source/base/object.cxx
index 403a1c6bb61d..bdd3862d8d52 100644
--- a/sot/source/base/object.cxx
+++ b/sot/source/base/object.cxx
@@ -63,7 +63,7 @@ SO2_IMPL_INVARIANT(SotObject)
|*
|* Beschreibung:
*************************************************************************/
-void SotObject::TestMemberObjRef( BOOL /*bFree*/ )
+void SotObject::TestMemberObjRef( sal_Bool /*bFree*/ )
{
}
@@ -73,7 +73,7 @@ void SotObject::TestMemberObjRef( BOOL /*bFree*/ )
|* Beschreibung:
*************************************************************************/
#ifdef TEST_INVARIANT
-void SotObject::TestMemberInvariant( BOOL /*bPrint*/ )
+void SotObject::TestMemberInvariant( sal_Bool /*bPrint*/ )
{
}
#endif
@@ -87,9 +87,9 @@ SotObject::SotObject()
: pAggList ( NULL )
, nStrongLockCount( 0 )
, nOwnerLockCount( 0 )
- , bOwner ( TRUE )
- , bSVObject ( FALSE )
- , bInClose ( FALSE )
+ , bOwner ( sal_True )
+ , bSVObject ( sal_False )
+ , bInClose ( sal_False )
{
SotFactory::IncSvObjectCount( this );
}
@@ -123,7 +123,7 @@ IUnknown * SotObject::GetInterface( const SvGlobalName & )
|*
|* Beschreibung
*************************************************************************/
-BOOL SotObject::IsSvObject() const
+sal_Bool SotObject::IsSvObject() const
{
return Owner() || bSVObject;
}
@@ -138,20 +138,20 @@ BOOL SotObject::IsSvObject() const
|* Objekte um 1 erhoeht, muss dies bei der Berechnung
|* des 0-RefCounts beruecksichtigt werden.
*************************************************************************/
-BOOL SotObject::ShouldDelete()
+sal_Bool SotObject::ShouldDelete()
{
if( !pAggList )
- return TRUE;
+ return sal_True;
SvAggregate & rMO = pAggList->GetObject( 0 );
if( rMO.bMainObj )
{
AddRef();
pAggList->GetObject( 0 ).pObj->ReleaseRef();
- return FALSE;
+ return sal_False;
}
- ULONG i;
+ sal_uIntPtr i;
for( i = 1; i < pAggList->Count(); i++ )
{
SvAggregate & rAgg = pAggList->GetObject( i );
@@ -162,7 +162,7 @@ BOOL SotObject::ShouldDelete()
AddRef();
// einen Aggregierten runterzaehlen
rAgg.pObj->ReleaseRef();
- return FALSE;
+ return sal_False;
}
}
AddNextRef(); // rekursion stoppen
@@ -175,7 +175,7 @@ BOOL SotObject::ShouldDelete()
delete pAggList;
pAggList = NULL;
// und zerstoeren, dies ist unabhaengig vom RefCount
- return TRUE;
+ return sal_True;
}
/*************************************************************************
@@ -212,7 +212,7 @@ SvAggregateMemberList & SotObject::GetAggList()
|*
|* Beschreibung
*************************************************************************/
-void SotObject::RemoveInterface( ULONG nPos )
+void SotObject::RemoveInterface( sal_uIntPtr nPos )
{
SvAggregate & rAgg = pAggList->GetObject( nPos );
if( !rAgg.bFactory )
@@ -238,7 +238,7 @@ void SotObject::RemoveInterface( SotObject * pObjP )
{
DBG_ASSERT( pObjP, "null pointer" );
DBG_ASSERT( pAggList, "no aggregation list" );
- ULONG i;
+ sal_uIntPtr i;
for( i = 0; i < pAggList->Count(); i++ )
{
SvAggregate & rAgg = pAggList->GetObject( i );
@@ -257,12 +257,12 @@ void SotObject::AddInterface( SotObject * pObjP )
{
pObjP->AddRef(); // Objekt festhalten
GetAggList();
- pAggList->Append( SvAggregate( pObjP, FALSE ) );
+ pAggList->Append( SvAggregate( pObjP, sal_False ) );
// sich selbst als Typecast-Verwalter eintragen
SvAggregateMemberList & rAList = pObjP->GetAggList();
DBG_ASSERT( !rAList.GetObject( 0 ).bMainObj, "try to aggregate twice" );
- rAList[ 0 ] = SvAggregate( this, TRUE );
+ rAList[ 0 ] = SvAggregate( this, sal_True );
}
/*************************************************************************
@@ -298,7 +298,7 @@ void * SotObject::DownAggCast( const SotFactory * pFact )
// geht den Pfad nur Richtung aggregierte Objekte
if( pAggList )
{
- for( ULONG i = 1; !pCast || i < pAggList->Count(); i++ )
+ for( sal_uIntPtr i = 1; !pCast || i < pAggList->Count(); i++ )
{
SvAggregate & rAgg = pAggList->GetObject( i );
if( rAgg.bFactory )
@@ -307,14 +307,14 @@ void * SotObject::DownAggCast( const SotFactory * pFact )
{
// On-Demand erzeugen, wenn Typ gebraucht
SotObjectRef aObj( CreateAggObj( rAgg.pFact ) );
- rAgg.bFactory = FALSE;
+ rAgg.bFactory = sal_False;
rAgg.pObj = aObj;
rAgg.pObj->AddRef();
// sich selbst als Typecast-Verwalter eintragen
SvAggregateMemberList & rAList = rAgg.pObj->GetAggList();
DBG_ASSERT( !rAList.GetObject( 0 ).bMainObj, "try to aggregate twice" );
- rAList[ 0 ] = SvAggregate( this, TRUE );
+ rAList[ 0 ] = SvAggregate( this, sal_True );
}
}
if( !rAgg.bFactory )
@@ -382,23 +382,23 @@ SotObject * SotObject::GetMainObj() const
}
//=========================================================================
-USHORT SotObject::FuzzyLock
+sal_uInt16 SotObject::FuzzyLock
(
- BOOL bLock, /* TRUE, lock. FALSE, unlock. */
- BOOL /*bIntern*/, /* TRUE, es handelt sich um einen internen Lock.
- FALSE, der Lock kam von aussen (Ole2, Ipc2) */
- BOOL bClose /* TRUE, Close aufrufen wenn letzte Lock */
+ sal_Bool bLock, /* sal_True, lock. sal_False, unlock. */
+ sal_Bool /*bIntern*/, /* sal_True, es handelt sich um einen internen Lock.
+ sal_False, der Lock kam von aussen (Ole2, Ipc2) */
+ sal_Bool bClose /* sal_True, Close aufrufen wenn letzte Lock */
)
/* [Beschreibung]
Erlaubte Parameterkombinationen:
- ( TRUE, TRUE, * ) -> interner Lock.
- ( FALSE, TRUE, TRUE ) -> interner Unlock mit Close,
+ ( sal_True, sal_True, * ) -> interner Lock.
+ ( sal_False, sal_True, sal_True ) -> interner Unlock mit Close,
wenn LockCount() == 0
- ( TRUE, FALSE, * ) -> externer Lock.
- ( FALSE, FALSE, TRUE ) -> externer Unlock mit Close,
+ ( sal_True, sal_False, * ) -> externer Lock.
+ ( sal_False, sal_False, sal_True ) -> externer Unlock mit Close,
wenn LockCount() == 0
- ( FALSE, FALSE, FALSE ) -> externer Unlock
+ ( sal_False, sal_False, sal_False ) -> externer Unlock
F"ur !Owner() wird der Aufruf an das externe Objekt weitergeleitet.
F"ur diese muss das <IOleItemContainer>-Interface zur Vef"ugung stehen.
@@ -411,7 +411,7 @@ USHORT SotObject::FuzzyLock
*/
{
SotObjectRef xHoldAlive( this );
- USHORT nRet;
+ sal_uInt16 nRet;
if( bLock )
{
AddRef();
@@ -431,7 +431,7 @@ USHORT SotObject::FuzzyLock
//=========================================================================
void SotObject::OwnerLock
(
- BOOL bLock /* TRUE, lock. FALSE, unlock. */
+ sal_Bool bLock /* sal_True, lock. sal_False, unlock. */
)
/* [Beschreibung]
@@ -467,23 +467,23 @@ void SotObject::RemoveOwnerLock()
}
//=========================================================================
-BOOL SotObject::DoClose()
+sal_Bool SotObject::DoClose()
{
- BOOL bRet = FALSE;
+ sal_Bool bRet = sal_False;
if( !bInClose )
{
SotObjectRef xHoldAlive( this );
- bInClose = TRUE;
+ bInClose = sal_True;
bRet = Close();
- bInClose = FALSE;
+ bInClose = sal_False;
}
return bRet;
}
//=========================================================================
-BOOL SotObject::Close()
+sal_Bool SotObject::Close()
{
- return TRUE;
+ return sal_True;
}